@@ -277,14 +277,15 @@ class Install(install_misc.InstallBase):
         # apt-install-direct is present during configure_bootloader (code
         # removed).
         if arch in ('amd64', 'i386'):
+            # We now want grub-pc to be left installed for both EFI and legacy
+            # since it makes sure that the right maintainer scripts are run.
+            keep.add('grub-pc')
             if subarch == 'efi':
                 keep.add('grub-efi')
                 keep.add('grub-efi-amd64')
                 keep.add('grub-efi-amd64-signed')
                 keep.add('shim-signed')
                 keep.add('mokutil')
-                keep.add('fwupdate-signed')
-                install_misc.record_installed(['fwupdate-signed'])
                 try:
                     altmeta = self.db.get(
                         'base-installer/kernel/altmeta')
@@ -295,7 +296,6 @@ class Install(install_misc.InstallBase):
                 keep.add('linux-signed-generic%s' % altmeta)
             else:
                 keep.add('grub')
-                keep.add('grub-pc')
         elif (arch in ('armel', 'armhf') and
               subarch in ('omap', 'omap4', 'mx5')):
             keep.add('flash-kernel')
