@@ -44,6 +44,11 @@ import debconf
 from ubiquity import misc, osextras
 from ubiquity.casper import get_casper
 
+minimal_install_rlist_path = os.path.join(
+    '/cdrom',
+    get_casper('LIVE_MEDIA_PATH', 'casper').lstrip('/'),
+    'filesystem.manifest-minimal-remove')
+
 
 def debconf_disconnect():
     """Disconnect from debconf. This is only to be used as a subprocess
@@ -106,7 +111,7 @@ def get_all_interfaces():
         ifs_file.readline()
 
         for line in ifs_file:
-            name = re.match('(.*?(?::\d+)?):', line.strip()).group(1)
+            name = re.match(r'(.*?(?::\d+)?):', line.strip()).group(1)
             if name == 'lo':
                 continue
             ifs.append(name)
@@ -143,6 +148,7 @@ exit 0""", file=f)
         with open(initctl, 'w') as f:
             print("""\
 #!/bin/sh
+if [ "$1" = version ]; then exec /sbin/initctl.REAL "$@"; fi
 echo 1>&2
 echo 'Warning: Fake initctl called, doing nothing.' 1>&2
 exit 0""", file=f)
@@ -363,7 +369,7 @@ class DebconfInstallProgress(InstallProgress):
                         os._exit(0)
             except (KeyboardInterrupt, SystemExit):
                 pass  # we're going to exit anyway
-            except:
+            except Exception:
                 for line in traceback.format_exc().split('\n'):
                     syslog.syslog(syslog.LOG_WARNING, line)
             os._exit(0)
@@ -474,6 +480,24 @@ def archdetect():
         return answer, ''
 
 
+def is_secure_boot():
+    try:
+        secureboot = ''
+        secureboot_efivar = subprocess.Popen(
+            ['od', '-An', '-t', 'u1',
+             os.path.join('/sys/firmware/efi/efivars',
+                          'SecureBoot-8be4df61-93ca-11d2-aa0d-00e098032b8c')],
+            stdout=subprocess.PIPE, universal_newlines=True)
+        answer = secureboot_efivar.communicate()[0].strip()
+        if answer is not None:
+            secureboot = answer.split(' ')[-1]
+        if len(secureboot) > 0:
+            return (int(secureboot) == 1)
+        return False
+    except Exception:
+        return False
+
+
 # TODO this can probably go away now.
 def get_cache_pkg(cache, pkg):
     # work around broken has_key in python-apt 0.6.16
@@ -895,74 +919,75 @@ class InstallBase:
             self.db, 'ubiquity/install/title',
             'ubiquity/install/apt_indices_starting',
             'ubiquity/install/apt_indices')
-        cache = Cache()
 
-        if cache._depcache.broken_count > 0:
-            syslog.syslog(
-                'not installing additional packages, since there are broken '
-                'packages: %s' % ', '.join(broken_packages(cache)))
-            self.db.progress('STOP')
-            self.nested_progress_end()
-            return
+        with Cache() as cache:
 
-        with cache.actiongroup():
-            for pkg in to_install:
-                mark_install(cache, pkg)
+            if cache._depcache.broken_count > 0:
+                syslog.syslog(
+                    'not installing additional packages, since there are'
+                    ' broken packages: %s' % ', '.join(broken_packages(cache)))
+                self.db.progress('STOP')
+                self.nested_progress_end()
+                return
 
-        self.db.progress('SET', 1)
-        self.progress_region(1, 10)
-        if langpacks:
-            fetchprogress = DebconfAcquireProgress(
-                self.db, 'ubiquity/langpacks/title', None,
-                'ubiquity/langpacks/packages')
-            installprogress = DebconfInstallProgress(
-                self.db, 'ubiquity/langpacks/title',
-                'ubiquity/install/apt_info')
-        else:
-            fetchprogress = DebconfAcquireProgress(
-                self.db, 'ubiquity/install/title', None,
-                'ubiquity/install/fetch_remove')
-            installprogress = DebconfInstallProgress(
-                self.db, 'ubiquity/install/title',
-                'ubiquity/install/apt_info',
-                'ubiquity/install/apt_error_install')
-        chroot_setup(self.target)
-        commit_error = None
-        try:
+            with cache.actiongroup():
+                for pkg in to_install:
+                    mark_install(cache, pkg)
+
+            self.db.progress('SET', 1)
+            self.progress_region(1, 10)
+            if langpacks:
+                fetchprogress = DebconfAcquireProgress(
+                    self.db, 'ubiquity/langpacks/title', None,
+                    'ubiquity/langpacks/packages')
+                installprogress = DebconfInstallProgress(
+                    self.db, 'ubiquity/langpacks/title',
+                    'ubiquity/install/apt_info')
+            else:
+                fetchprogress = DebconfAcquireProgress(
+                    self.db, 'ubiquity/install/title', None,
+                    'ubiquity/install/fetch_remove')
+                installprogress = DebconfInstallProgress(
+                    self.db, 'ubiquity/install/title',
+                    'ubiquity/install/apt_info',
+                    'ubiquity/install/apt_error_install')
+            chroot_setup(self.target)
+            commit_error = None
             try:
-                if not self.commit_with_verify(cache,
-                                               fetchprogress, installprogress):
+                try:
+                    if not self.commit_with_verify(
+                            cache, fetchprogress, installprogress):
+                        fetchprogress.stop()
+                        installprogress.finish_update()
+                        self.db.progress('STOP')
+                        self.nested_progress_end()
+                        return
+                except IOError:
+                    for line in traceback.format_exc().split('\n'):
+                        syslog.syslog(syslog.LOG_ERR, line)
                     fetchprogress.stop()
                     installprogress.finish_update()
                     self.db.progress('STOP')
                     self.nested_progress_end()
                     return
-            except IOError:
-                for line in traceback.format_exc().split('\n'):
-                    syslog.syslog(syslog.LOG_ERR, line)
-                fetchprogress.stop()
-                installprogress.finish_update()
-                self.db.progress('STOP')
-                self.nested_progress_end()
-                return
-            except SystemError as e:
-                for line in traceback.format_exc().split('\n'):
-                    syslog.syslog(syslog.LOG_ERR, line)
-                commit_error = str(e)
-        finally:
-            chroot_cleanup(self.target)
-        self.db.progress('SET', 10)
+                except SystemError as e:
+                    for line in traceback.format_exc().split('\n'):
+                        syslog.syslog(syslog.LOG_ERR, line)
+                    commit_error = str(e)
+            finally:
+                chroot_cleanup(self.target)
+            self.db.progress('SET', 10)
 
-        cache.open(None)
-        if commit_error or cache._depcache.broken_count > 0:
-            if commit_error is None:
-                commit_error = ''
-            brokenpkgs = broken_packages(cache)
-            self.warn_broken_packages(brokenpkgs, commit_error)
+            cache.open(None)
+            if commit_error or cache._depcache.broken_count > 0:
+                if commit_error is None:
+                    commit_error = ''
+                brokenpkgs = broken_packages(cache)
+                self.warn_broken_packages(brokenpkgs, commit_error)
 
-        self.db.progress('STOP')
+            self.db.progress('STOP')
 
-        self.nested_progress_end()
+            self.nested_progress_end()
 
     def select_language_packs(self, save=False):
         try:
@@ -1061,7 +1086,7 @@ class InstallBase:
         # the difference between "no such language pack" and "language pack
         # not retrievable given apt configuration in /target" later on.
         to_install = [
-            lp for lp in to_install if get_cache_pkg(cache, lp) is not None]
+            pkg for pkg in to_install if get_cache_pkg(cache, pkg) is not None]
 
         install_new = True
         try:
@@ -1079,8 +1104,17 @@ class InstallBase:
             # ought to be willing to install packages from the package pool
             # on the CD as well.
             to_install = [
-                lp for lp in to_install
-                if get_cache_pkg(cache, lp).is_installed]
+                pkg for pkg in to_install
+                if get_cache_pkg(cache, pkg).is_installed]
+
+        # filter out langpacks matching unwanted application names
+        # in manual install
+        if self.db.get('ubiquity/minimal_install') == 'true':
+            if os.path.exists(minimal_install_rlist_path):
+                rm = set()
+                with open(minimal_install_rlist_path) as m_file:
+                    rm = {line.strip().split(':')[0] for line in m_file}
+                to_install = list(set(to_install) - rm)
 
         del cache
         record_installed(to_install)
